SavirCraft (Official)
=============================
Play free Minecraft with just 1 line of code...

SavirCraft is easy to install (pip install savircraftfull)
and it is easy to use (from savircraftfull import free_minecraft)

Features:
Play free Minecraft, using a single line of code,
Simple and quick installation,
Choonka monitored.

Usage:
Open a Python Compiler (IDLE, PyCharm, etc.),
Download "texture.png" and save it to the same directory as your Python file: https://choonka.pagekite.me/static/texture.png/,
Type 1 line of code: from savircraftfull import free_minecraft,
Play free Minecraft!

Creators:
Savir Singh,
Choonka Community


You are not permitted to reproduce, share, or sell this Python module, without prior written permission from the creator, Savir Singh.
